@@ -555,9 +555,9 @@ gnm_cell_array_bound (GnmCell const *cell, GnmRange *res)
 
 /**
  * gnm_cell_is_array:
- * @cell: #GnmCell
+ * @cell: (nullable): #GnmCell
  *
- * Returns %TRUE is @cell is part of an array
+ * Returns: %TRUE if @cell is part of an array
  **/
 gboolean
 gnm_cell_is_array (GnmCell const *cell)
@@ -596,7 +596,8 @@ gnm_cell_is_nonsingleton_array (GnmCell const *cell)
  * gnm_cell_get_rendered_value: (skip)
  * @cell: #GnmCell
  *
- * Returns: (transfer none): The #GnmRenderedValue for the cell.
+ * Returns: (transfer none) (nullable): The #GnmRenderedValue for the cell,
+ * if one currently exists.
  **/
 GnmRenderedValue *
 gnm_cell_get_rendered_value (GnmCell const *cell)
@@ -662,10 +663,13 @@ gnm_cell_render_value (GnmCell const *cell, gboolean allow_variable_width)
 
 /*
  * gnm_cell_get_rendered_text:
+ * @cell: cell to query
  *
  * Warning: use this only when you really want what is displayed on the
  * screen.  If the user has decided to display formulas instead of values
  * then that is what you get.
+ *
+ * Returns: (transfer full): text in cell.
  */
 char *
 gnm_cell_get_rendered_text (GnmCell *cell)
@@ -702,7 +706,9 @@ gnm_cell_get_render_color (GnmCell const *cell)
  * @cell: the cell from which we want to pull the content from
  *
  * Returns: (transfer full): a text expression if the cell contains a
- * formula, or a string representation of the value.
+ * formula, or a string representation of the value.  For formulas this
+ * includes an equals sign.  For values, an initial single quote may
+ * be added to force text interpretation of a string.
  */
 char *
 gnm_cell_get_entered_text (GnmCell const *cell)
@@ -950,9 +956,7 @@ gnm_cell_rendered_height (GnmCell const *cell)
 	g_return_val_if_fail (cell != NULL, 0);
 
 	rv = gnm_cell_get_rendered_value (cell);
-	return rv
-		? PANGO_PIXELS (rv->layout_natural_height)
-		: 0;
+	return rv ?  gnm_rendered_value_get_height (rv) : 0;
 }
 
 /*
@@ -966,9 +970,7 @@ gnm_cell_rendered_width (GnmCell const *cell)
 	g_return_val_if_fail (cell != NULL, 0);
 
 	rv = gnm_cell_get_rendered_value (cell);
-	return rv
-		? PANGO_PIXELS (rv->layout_natural_width)
-		: 0;
+	return rv ?  gnm_rendered_value_get_width (rv) : 0;
 }
 
 int
@@ -1168,3 +1170,22 @@ gnm_cell_get_type (void)
  * or contains a value.
  */
 extern inline gboolean gnm_cell_has_expr (GnmCell const *cell);
+
+/**
+ * gnm_cell_needs_recalc:
+ * @cell: #GnmCell
+ *
+ * Returns: %TRUE if @cell needs recalculations.
+ */
+extern inline gboolean gnm_cell_needs_recalc (GnmCell const *cell);
+
+// Internal
+extern inline gboolean gnm_cell_expr_is_linked (GnmCell const *cell);
+
+/**
+ * gnm_cell_is_merged:
+ * @cell: #GnmCell
+ *
+ * Returns: %TRUE if @cell is the corner of a merged region.
+ */
+extern inline gboolean gnm_cell_is_merged (GnmCell const *cell);
