@@ -61,7 +61,8 @@ col_row_info_get_type (void)
 double
 colrow_compute_pixel_scale (Sheet const *sheet, gboolean horizontal)
 {
-	double scale = gnm_app_display_dpi_get (horizontal) / 72.0;
+	// double scale = gnm_app_display_dpi_get (horizontal) / 72.0;
+	double scale = sheet->priv->pixels_per_pt;
 	if (sheet) {
 		scale *= sheet->last_zoom_factor_used;
 	} else {
@@ -144,7 +145,7 @@ col_row_info_is_empty (ColRowInfo const *cri)
  * @a: First #ColRowInfo
  * @b: Second #ColRowInfo
  *
- * Returns %TRUE if the infos are equivalent.
+ * Returns: %TRUE if the infos are equivalent.
  **/
 gboolean
 col_row_info_equal (ColRowInfo const *a, ColRowInfo const *b)
@@ -686,9 +687,12 @@ colrow_set_states (Sheet *sheet, gboolean is_cols,
 				if (segment != NULL) {
 					int const sub = COLROW_SUB_INDEX (i);
 					ColRowInfo *cri = segment->info[sub];
-					if (cri != NULL) {
+					if (cri != NULL && !col_row_info_is_default (cri)) {
 						segment->info[sub] = NULL;
 						colrow_free (cri);
+						// We may have created cells so NULL is
+						// not acceptable.
+						(void)sheet_colrow_fetch (sheet, i, is_cols);
 					}
 				}
 			} else {
@@ -788,14 +792,15 @@ rows_height_update (Sheet *sheet, GnmRange const *range, gboolean shrink)
 	 * just contents.  Empty cells will cause resize also */
 	colrow_autofit (sheet, range, FALSE, FALSE,
 			FALSE, !shrink,
-			NULL, NULL);
+			NULL, NULL,
+			TRUE);
 }
 
 /* ------------------------------------------------------------------------- */
 
 struct cb_autofit {
 	Sheet *sheet;
-	const GnmRange *range;
+	GnmRange range;
 	gboolean ignore_strings;
 	gboolean min_current;
 	gboolean min_default;
@@ -811,7 +816,8 @@ cb_autofit_col (GnmColRowIter const *iter, gpointer data_)
 		return FALSE;
 
 	size = sheet_col_size_fit_pixels (data->sheet, iter->pos,
-		 data->range->start.row, data->range->end.row,
+					  data->range.start.row,
+					  data->range.end.row,
 		 data->ignore_strings);
 	/* FIXME: better idea than this?  */
 	max = 50 * sheet_col_get_default_size_pixels (data->sheet);
@@ -839,7 +845,8 @@ cb_autofit_row (GnmColRowIter const *iter, gpointer data_)
 		return FALSE;
 
 	size = sheet_row_size_fit_pixels (data->sheet, iter->pos,
-		 data->range->start.col, data->range->end.col,
+					  data->range.start.col,
+					  data->range.end.col,
 		 data->ignore_strings);
 	max = 20 * sheet_row_get_default_size_pixels (data->sheet);
 	size = MIN (size, max);
@@ -868,6 +875,8 @@ cb_autofit_row (GnmColRowIter const *iter, gpointer data_)
  *     colrow_restore_state_group.
  * @sizes: (out) (optional): old sizes appropriate for
  *     colrow_restore_state_group.
+ * @reasonable_effort: if %TRUE, this function may skip some cells from really
+ *    big ranges.
  *
  * This function autofits columns or rows in @range as specified by
  * @is_cols.  Only cells in @range are considered for the sizing
@@ -879,25 +888,36 @@ colrow_autofit (Sheet *sheet, const GnmRange *range, gboolean is_cols,
 		gboolean ignore_strings,
 		gboolean min_current, gboolean min_default,
 		ColRowIndexList **indices,
-		ColRowStateGroup **sizes)
+		ColRowStateGroup **sizes,
+		gboolean reasonable_effort)
 {
 	struct cb_autofit data;
 	int a, b;
 	ColRowHandler handler;
 
 	data.sheet = sheet;
-	data.range = range;
+	data.range = *range;
 	data.ignore_strings = ignore_strings;
 	data.min_current = min_current;
 	data.min_default = min_default;
 
+	if (reasonable_effort) {
+		const int MAX_HEIGHT = 10000;
+		const int MAX_WIDTH = 1000;
+
+		if (range_height (&data.range) > MAX_HEIGHT)
+			data.range.end.row = data.range.start.row + MAX_HEIGHT - 1;
+		if (range_width (&data.range) > MAX_WIDTH)
+			data.range.end.col = data.range.start.col + MAX_WIDTH - 1;
+	}
+
 	if (is_cols) {
-		a = range->start.col;
-		b = range->end.col;
+		a = data.range.start.col;
+		b = data.range.end.col;
 		handler = cb_autofit_col;
 	} else {
-		a = range->start.row;
-		b = range->end.row;
+		a = data.range.start.row;
+		b = data.range.end.row;
 		handler = cb_autofit_row;
 	}
 
@@ -923,7 +943,7 @@ void
 colrow_autofit_col (Sheet *sheet, GnmRange *r)
 {
 	colrow_autofit (sheet, r, TRUE, TRUE,
-			TRUE, FALSE, NULL, NULL);
+			TRUE, FALSE, NULL, NULL, TRUE);
 	sheet_foreach_cell_in_region (sheet, CELL_ITER_IGNORE_BLANK,
 				      r->start.col, 0,
 				      r->end.col, -1,
@@ -940,7 +960,7 @@ void
 colrow_autofit_row (Sheet *sheet, GnmRange *r)
 {
 	colrow_autofit (sheet, r, FALSE, FALSE,
-			TRUE, FALSE, NULL, NULL);
+			TRUE, FALSE, NULL, NULL, TRUE);
 }
 
 /*****************************************************************************/
