@@ -776,7 +776,7 @@ gee_create_tooltip (GnmExprEntry *gee, gchar const *str,
 	char *text = NULL;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (gee->entry));
-	gtk_widget_add_events(toplevel, GDK_FOCUS_CHANGE_MASK);
+	gtk_widget_add_events (toplevel, GDK_FOCUS_CHANGE_MASK);
 	if (gee->tooltip.handlerid == 0)
 		gee->tooltip.handlerid = g_signal_connect
 			(G_OBJECT (toplevel), "focus-out-event",
@@ -1806,7 +1806,7 @@ gee_prepare_range (GnmExprEntry const *gee, GnmRangeRef *dst)
 		GnmRange r;
 		GnmRange const *merge;
 		Sheet *start_sheet, *end_sheet;
-		gnm_rangeref_normalize(dst,
+		gnm_rangeref_normalize (dst,
 			eval_pos_init_pos (&ep, gee->sheet, &gee->pp.eval),
 			&start_sheet, &end_sheet,
 			&r);
@@ -2562,14 +2562,14 @@ gnm_expr_entry_can_rangesel (GnmExprEntry *gee)
 
 	g_return_val_if_fail (GNM_EXPR_ENTRY_IS (gee), FALSE);
 
-	if (wbc_gtk_get_guru (gee->wbcg) != NULL &&
+	if (wbcg_get_guru (gee->wbcg) != NULL &&
 	    gee == gee->wbcg->edit_line.entry)
 		return FALSE;
 
 	text = gtk_entry_get_text (gee->entry);
 
 	/* We need to be editing an expression */
-	if (wbc_gtk_get_guru (gee->wbcg) == NULL &&
+	if (wbcg_get_guru (gee->wbcg) == NULL &&
 	    gnm_expr_char_start_p (text) == NULL)
 		return FALSE;
 
@@ -2680,7 +2680,7 @@ gnm_expr_entry_parse (GnmExprEntry *gee, GnmParsePos const *pp,
  * A small convenience routine.  Think long and hard before using this.
  * There are lots of parse routines that serve the common case.
  *
- * Returns: The content of the entry.  Caller should not modify the result.
+ * Returns: (transfer none): The content of the entry.
  **/
 char const *
 gnm_expr_entry_get_text	(GnmExprEntry const *gee)
@@ -2694,7 +2694,7 @@ gnm_expr_entry_get_text	(GnmExprEntry const *gee)
  * @gee: GnmExprEntry
  * @sheet: the sheet where the cell range is evaluated.
  *
- * Returns a (GnmValue *) of type VALUE_CELLRANGE if the @range was
+ * Returns: (nullable): #GnmValue of type VALUE_CELLRANGE if the range was
  *	successfully parsed or %NULL on failure.
  */
 GnmValue *
@@ -2735,7 +2735,6 @@ gnm_expr_entry_parse_as_value (GnmExprEntry *gee, Sheet *sheet)
  *         the range given does not include a sheet specification.
  *
  * Returns: (element-type GnmValue) (transfer full): a list of ranges
- * (as #GnmValue).
  */
 GSList *
 gnm_expr_entry_parse_as_list (GnmExprEntry *gee, Sheet *sheet)
